# The Big Box of HTML

## Validators
 - [W3C Markup Validation Service](https://validator.w3.org/) - The original HTML validator for all your HTML validating needs
 - [Structured Data Linter](http://linter.structured-data.org/) - Check your page's microdata and structured data.

## Testing Tools
 - [.resizr](http://resizr.co/) - Responsive website testing tool
 - [SSLlabs](https://www.ssllabs.com/ssltest/) - THE SSL server test. Grades your website from A+ to F on it's SSL capabilities.
 - [WebPagetest](http://www.webpagetest.org/) - A web page performance testing tool. Provides a detailed analysis and suggest ways to improve.
 - [justice](http://okor.github.io/justice/) - An alternative web page performance monitor.
 - [Tota11y](http://khan.github.io/tota11y/) - A web page accessability testing tool. For developers that don't use assitive technologies themselves.
 - [lowvision.support](http://lowvision.support/) - Another website accessibility testing tool. This one lets you simulate different types of colourblindness and several other conditions right in your web browser. Strange url: yes, Bad tool: no (it wouldn't be featured here if it wasn't!).
 - [RulersGuides.js](http://mark-rolich.github.io/RulersGuides.js/) - A JS bookmarklet that brings rulers and guidelines to any webpage.

## Content & Generators
 - [Epic Favicon Generator](https://epicfavicongenerator.com/) - A simple no-fuss favicon generator.
 - [Cat Ipsum](http://catipsum.com/) - A furrier alternative to Lorem Ipsum
 - [placehold.it](https://placehold.it/) - A simple no-fuss placeholder image service
 - [placekitten.com](http://placekitten.com/) - A placeholder image service that gives you pictures of kittens
 - [Lorem Pixel](http://lorempixel.com/) - An alternative to placekitten.com.
 - [playr](http://plyr.io/) - A super simple HTML5 video and audio player

 - [High Resolution Browser Logos](https://github.com/alrra/browser-logos#high-resolution-browser-logos) - A GitHub repository that contains high resolution logos for every browser under the sun

 - [htpasswd generator](http://aspirine.org/htpasswd_en.html) - Online tool that generates .htpasswd entries. Useful for both apache and nginx.

## Layout
 - [Peppermint touch slider](http://wd.dizaina.net/en/scripts/peppermint/) - Easy to use library for creating sliders.
 - [watermark.js](http://brianium.github.io/watermarkjs/) - watermark images in the browser.
 - [Stickers.js](http://stickerjs.cmiscm.com/) - Apply an (interactive!) sticker effect to an image
 - [Stretchy](http://leaverou.github.io/stretchy/) - Easy form element autoresizing
 - [wallop](http://pedroduarte.me/wallop/) - Library to show / hide stuff, includes a previous / next system.
 - [houdini](https://github.com/cferdinandi/houdini/) - A super simple script to make an element collapsible.
 - [layzr.js](http://callmecavs.github.io/layzr.js/) - An easy to use lazy image loading script
 - [[be]lazy.js](http://dinbror.dk/blazy/) - An alternative to the above. Looks slightly more advanced, but also more complex.
 - [tabby](https://github.com/cferdinandi/tabby/) - A drop-in easy to use tab system. Works using ids, and supports both `<a>` tags and buttons.

## Accessibility
 - [abbr-touch](https://github.com/Tyriar/abbr-touch) - Make the `title` attribute of the `<abbr>` (abbreviation) HTML element accessible to touch screen users
 - [Help users checkout faster with autofill](http://updates.html5rocks.com/2015/06/checkout-faster-with-Autofill) - A great article about using the `autocomplete` attribute to indicate what kind of content each input box should contain

## Polyfills
 - [formfive](http://etiennetalbot.github.io/formFive/) - HTML5 form support for legacy browsers.

## Colour Pickers
 - [Bumblemonkey Colour Picker](http://bumblemonkey.com/picker/picker.html) - A simple colour picker. Also converts RGB to Hex and vice versa.
 - [ColorBlendy](http://colorblendy.com/) - Blend colors with different modes (e.g. multiply, overlay, dodge, etc.)

## Fonts
 - [webfont-test](http://webfont-test.com/) - Compare up to 3 fonts at once
 - [Google Fonts on Github](https://github.com/google/fonts) - A repository that contains the fonts available on [Google Fonts](https://www.google.com/fonts).
 - [Font Library](http://katydecorah.com/font-library/) - An open source project that is tagging all the Google Fonts.
 - [&what;](http://www.amp-what.com/) - Not strictly a font tool, but still useful. This website lets you search a considerably sized library of unicode characters and presents you with their HTML entity form.

### Icon fonts and Equivalent
 - [Font Awesome](http://fontawesome.io/) - A cool icon font with 519(!) icons
 - [Open Iconic](https://useiconic.com/open/) - An open source version of a much larger commerical icon set. Still good - has nice clear icons for use in many different projects.

## Packaging Tools
 - [NW.js](http://nwjs.io/) - Previously known as `node-webkit`, this tool lets you package your HTML / CSS / JS app into a bundle (native for your target desktop platform) with Blink & Node.JS.
 - [Electron](http://electron.atom.io/) - An alternative to the above. Looks to be smaller, but I don't really know how it works.

## Tutorials and References
 - [HTML5 Semantic Element Flowchart](http://html5doctor.com/downloads/h5d-sectioning-flowchart.png) - Don't know which semantic HTML5 element to use? Use this flowchart to find out!

 - [Feditor.IO](http://feditor.io/) - Another online HTML / CSS / JS playground. Doesn't have a save function from what I can see, but apart from that it looks quite good.
 - [CodeMyUI.com](http://codemyui.com/) - A curated collection of code snippets. A bit like this repository actually!

## Support Websites
This section is a bit different - it contains link to sites that you might want to link to if a user of your website doesn't support a technology that you require.
 - [enable-javascript.com](http://enable-javascript.com/) - Shows the user how to enable javascript in their browser
 - [What Browser?](https://whatbrowser.org/) - Useful to link to if a user has an outdated browser
 - [Browse Happy](http://browsehappy.com) - Another site to link your visitors what don't have an up to date browser to. Created by Wordpress.

## Other
 - [SRI Hash Generator](https://srihash.org/) - Compute the SRI hash for the resource at a given url. See [cloudflare's blog post](https://blog.cloudflare.com/an-introduction-to-javascript-based-ddos/) (Scroll to the section on "Subresource Integrity") for more information.
